==> com.liferay.account.admin.web-1.0.2.jar: META-INF/resources/account_users_admin/js/ManagementToolbarDefaultEventHandler.es.js <==
Liferay.Loader.define("account-admin-web@1.0.2/account_users_admin/js/ManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var ManagementToolbarDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(ManagementToolbarDefaultEventHandler, _DefaultEventHandler);

    function ManagementToolbarDefaultEventHandler() {
      _classCallCheck(this, ManagementToolbarDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(ManagementToolbarDefaultEventHandler).apply(this, arguments));
    }

    _createClass(ManagementToolbarDefaultEventHandler, [{
      key: "activateAccountUsers",
      value: function activateAccountUsers(itemData) {
        this._updateAccountUsers(itemData.activateAccountUsersURL);
      }
    }, {
      key: "deactivateAccountUsers",
      value: function deactivateAccountUsers(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-deactivate-the-selected-users'))) {
          this._updateAccountUsers(itemData.deactivateAccountUsersURL);
        }
      }
    }, {
      key: "deleteAccountUsers",
      value: function deleteAccountUsers(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-delete-the-selected-users'))) {
          this._updateAccountUsers(itemData.deleteAccountUsersURL);
        }
      }
    }, {
      key: "selectAccountEntries",
      value: function selectAccountEntries(itemData) {
        this._openAccountEntrySelector(Liferay.Language.get('select'), this.ns('selectAccountEntries'), Liferay.Language.get(itemData.dialogTitle), itemData.accountEntriesSelectorURL, function (selectedItems) {
          var redirectURL = Liferay.Util.PortletURL.createPortletURL(itemData.redirectURL, {
            accountEntriesNavigation: 'accounts',
            accountEntryIds: selectedItems.value
          });
          window.location.href = redirectURL;
        });
      }
    }, {
      key: "addAccountUser",
      value: function addAccountUser(itemData) {
        Liferay.Util.selectEntity({
          dialog: {
            constrain: true,
            modal: true
          },
          eventName: this.ns('addAccountUser'),
          id: this.ns('addAccountUser'),
          title: Liferay.Language.get(itemData.dialogTitle),
          uri: itemData.accountEntrySelectorURL
        }, function (event) {
          var addAccountUserURL = Liferay.Util.PortletURL.createPortletURL(itemData.addAccountUserURL, {
            accountEntryId: event.accountentryid
          });
          window.location.href = addAccountUserURL;
        });
      }
    }, {
      key: "_openAccountEntrySelector",
      value: function _openAccountEntrySelector(dialogButtonLabel, dialogEventName, dialogTitle, accountEntrySelectorURL, callback) {
        var itemSelectorDialog = new _frontendJsWeb.ItemSelectorDialog({
          buttonAddLabel: dialogButtonLabel,
          eventName: dialogEventName,
          title: dialogTitle,
          url: accountEntrySelectorURL
        });
        itemSelectorDialog.on('selectedItemChange', function (event) {
          if (event.selectedItem) {
            callback(event.selectedItem);
          }
        });
        itemSelectorDialog.open();
      }
    }, {
      key: "_updateAccountUsers",
      value: function _updateAccountUsers(url) {
        var form = this.one('#fm');
        Liferay.Util.postForm(form, {
          data: {
            accountUserIds: Liferay.Util.listCheckedExcept(form, this.ns('allRowIds'))
          },
          url: url
        });
      }
    }]);

    return ManagementToolbarDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  var _default = ManagementToolbarDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=ManagementToolbarDefaultEventHandler.es.js.map
});
//# sourceMappingURL=ManagementToolbarDefaultEventHandler.es.js.map

==> com.liferay.account.admin.web-1.0.21.jar: META-INF/resources/account_users_admin/js/ManagementToolbarDefaultEventHandler.es.js <==
Liferay.Loader.define("account-admin-web@1.0.21/account_users_admin/js/ManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var ManagementToolbarDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(ManagementToolbarDefaultEventHandler, _DefaultEventHandler);

    function ManagementToolbarDefaultEventHandler() {
      _classCallCheck(this, ManagementToolbarDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(ManagementToolbarDefaultEventHandler).apply(this, arguments));
    }

    _createClass(ManagementToolbarDefaultEventHandler, [{
      key: "activateAccountUsers",
      value: function activateAccountUsers(itemData) {
        this._updateAccountUsers(itemData.activateAccountUsersURL);
      }
    }, {
      key: "deactivateAccountUsers",
      value: function deactivateAccountUsers(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-deactivate-the-selected-users'))) {
          this._updateAccountUsers(itemData.deactivateAccountUsersURL);
        }
      }
    }, {
      key: "deleteAccountUsers",
      value: function deleteAccountUsers(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-delete-the-selected-users'))) {
          this._updateAccountUsers(itemData.deleteAccountUsersURL);
        }
      }
    }, {
      key: "selectAccountEntries",
      value: function selectAccountEntries(itemData) {
        this._openAccountEntrySelector(Liferay.Language.get('select'), this.ns('selectAccountEntries'), Liferay.Language.get(itemData.dialogTitle), itemData.accountEntriesSelectorURL, function (selectedItems) {
          var redirectURL = Liferay.Util.PortletURL.createPortletURL(itemData.redirectURL, {
            accountEntriesNavigation: 'accounts',
            accountEntryIds: selectedItems.value
          });
          window.location.href = redirectURL;
        });
      }
    }, {
      key: "addAccountUser",
      value: function addAccountUser(itemData) {
        (0, _frontendJsWeb.openModal)({
          id: this.ns('addAccountUser'),
          onSelect: function onSelect(selectedItem) {
            var addAccountUserURL = (0, _frontendJsWeb.createPortletURL)(itemData.addAccountUserURL, {
              accountEntryId: selectedItem.accountentryid
            });
            (0, _frontendJsWeb.navigate)(addAccountUserURL);
          },
          selectEventName: this.ns('selectAccountEntry'),
          title: Liferay.Language.get(itemData.dialogTitle),
          url: itemData.accountEntrySelectorURL
        });
      }
    }, {
      key: "_openAccountEntrySelector",
      value: function _openAccountEntrySelector(dialogButtonLabel, dialogEventName, dialogTitle, accountEntrySelectorURL, callback) {
        var itemSelectorDialog = new _frontendJsWeb.ItemSelectorDialog({
          buttonAddLabel: dialogButtonLabel,
          eventName: dialogEventName,
          title: dialogTitle,
          url: accountEntrySelectorURL
        });
        itemSelectorDialog.on('selectedItemChange', function (event) {
          if (event.selectedItem) {
            callback(event.selectedItem);
          }
        });
        itemSelectorDialog.open();
      }
    }, {
      key: "_updateAccountUsers",
      value: function _updateAccountUsers(url) {
        var form = this.one('#fm');
        Liferay.Util.postForm(form, {
          data: {
            accountUserIds: Liferay.Util.listCheckedExcept(form, this.ns('allRowIds'))
          },
          url: url
        });
      }
    }]);

    return ManagementToolbarDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  var _default = ManagementToolbarDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=ManagementToolbarDefaultEventHandler.es.js.map
});
//# sourceMappingURL=ManagementToolbarDefaultEventHandler.es.js.map
